Crate restate_sdk_shared_core

Crate restate_sdk_shared_core 

Re-exports

pub use error::Error;

Modules

error
fmt

Structs

AwakeableHandle
CallHandle
CoreVM
EntryRetryInfo
Header
Input
NotificationHandle
PayloadOptions
Options for syscalls that involve payload serialization.
ResponseHead
RunHandle
SendHandle
Target
TerminalFailure
Terminal failure
VMOptions

Enums

AttachInvocationTarget
AwaitResponse
AwaitingOnPolicy
CommandRelationship
Used in notify_error to specify which command this error relates to.
CommandType
ImplicitCancellationOption
JournalMismatchRetryBehavior
Defines how the state machine reacts to journal mismatch (non-determinism) errors, that is errors carrying the JOURNAL_MISMATCH status code.
NonDeterministicChecksOption
NonEmptyValue
OnMaxAttempts
What to do when a RetryPolicy runs out of attempts or duration.
RetryPolicy
This struct represents the policy to execute retries.
RunExitResult
State
UnresolvedFuture
Value
Version

Constants

CANCEL_NOTIFICATION_HANDLE

Traits

HeaderMap
VM

Type Aliases

VMResult