pub enum RetryPolicy {
Infinite,
None,
FixedDelay {
interval: Option<Duration>,
max_attempts: Option<u32>,
max_duration: Option<Duration>,
on_max_attempts: OnMaxAttempts,
},
Exponential {
initial_interval: Duration,
factor: f32,
max_interval: Option<Duration>,
max_attempts: Option<u32>,
max_duration: Option<Duration>,
on_max_attempts: OnMaxAttempts,
},
}Expand description
This struct represents the policy to execute retries.
Variants
Infinite
Infinite
Infinite retry strategy.
None
None
No retry strategy, fail on first failure.
FixedDelay
Fixed delay
Retry with a fixed delay strategy.
Fields
interval: Option<Duration>Interval
Interval between retries. If none, the runtime will provide one based on the invoker retry policy.
max_attempts: Option<u32>Max attempts
Gives up retrying when either this number of attempts is reached,
or max_duration (if set) is reached first.
Infinite retries if this field and max_duration are unset.
max_duration: Option<Duration>Max duration
Gives up retrying when either the retry loop lasted for this given max duration,
or max_attempts (if set) is reached first.
Infinite retries if this field and max_attempts are unset.
on_max_attempts: OnMaxAttemptsOn max attempts
What to do once max_attempts or max_duration is reached.
Exponential
Exponential
Retry with an exponential strategy. The next retry is computed as min(last_retry_interval * factor, max_interval).
Fields
factor: f32Factor
The factor to use to compute the next retry attempt. This value should be higher than 1.0
max_attempts: Option<u32>Max attempts
Gives up retrying when either this number of attempts is reached,
or max_duration (if set) is reached first.
Infinite retries if this field and max_duration are unset.
max_duration: Option<Duration>Max duration
Gives up retrying when either the retry loop lasted for this given max duration,
or max_attempts (if set) is reached first.
Infinite retries if this field and max_attempts are unset.
on_max_attempts: OnMaxAttemptsOn max attempts
What to do once max_attempts or max_duration is reached.
Implementations
Sourceimpl RetryPolicy
impl RetryPolicy
pub fn fixed_delay( interval: Option<Duration>, max_attempts: Option<u32>, max_duration: Option<Duration>, on_max_attempts: OnMaxAttempts, ) -> Self
pub fn exponential( initial_interval: Duration, factor: f32, max_attempts: Option<u32>, max_interval: Option<Duration>, max_duration: Option<Duration>, on_max_attempts: OnMaxAttempts, ) -> Self