UnresolvedFuture

Enum UnresolvedFuture 

#[non_exhaustive]
pub enum UnresolvedFuture { Single(NotificationHandle), FirstCompleted(Vec<UnresolvedFuture>), AllCompleted(Vec<UnresolvedFuture>), FirstSucceededOrAllFailed(Vec<UnresolvedFuture>), AllSucceededOrFirstFailed(Vec<UnresolvedFuture>), Unknown(Vec<UnresolvedFuture>), }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Single(NotificationHandle)

Waiting only this handle.



FirstCompleted(Vec<UnresolvedFuture>)

Resolve as soon as any one child future completes with success, or with failure (same as JS Promise.race).



AllCompleted(Vec<UnresolvedFuture>)

Wait for every child to complete, regardless of success or failure (same as JS Promise.allSettled).



FirstSucceededOrAllFailed(Vec<UnresolvedFuture>)

Resolve on the first success; fail only if all children fail (same as JS Promise.any).



AllSucceededOrFirstFailed(Vec<UnresolvedFuture>)

Resolve when all children succeed; short-circuit on the first failure (same as JS Promise.all).



Unknown(Vec<UnresolvedFuture>)

Unknown combinator. This should be used when the future type is not known by the SDK, or not representable by the other future types.