#[non_exhaustive]pub struct Input {
pub invocation_id: String,
pub random_seed: u64,
pub key: String,
pub headers: Vec<Header>,
pub input: Bytes,
pub scope: Option<String>,
pub limit_key: Option<String>,
pub idempotency_key: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.invocation_id: Stringrandom_seed: u64key: Stringheaders: Vec<Header>input: Bytesscope: Option<String>Scope for this invocation, if it was called within a scope. Since V7.
limit_key: Option<String>Limit key for this invocation, if one was provided. Since V7.
idempotency_key: Option<String>Idempotency key for this invocation, if one was provided. Since V7.